@@ -9,8 +9,6 @@ def validate_id(model_id: str):
         raise click.BadParameter("ID cannot be empty")
     if " " in model_id:
         raise click.BadParameter("ID cannot contain spaces")
-    if not model_id.isalnum():
-        raise click.BadParameter("ID cannot contain special characters")
     return model_id
 
 
